<?php

namespace App\Http\Controllers;


use App\Deposit;
use App\Transaction;
use App\Withdraw;
use Session;
use App\Admin;
use App\Setting;
use App\Advertisement;
use App\Hyip;
use App\User;
use Carbon\Carbon;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Hash;
use Mail;
use Intervention\Image\Facades\Image;

class AdminDashboardController extends Controller
{



    public function loginPage()
    {
        if (Auth::user()){
            return  redirect()->route('admin.dashboard');
        }
        return redirect()->route('admin.login');
    }

    public function loginForm()
    {
        return view('admin.page-login');
    }

    public function login(Request $request)
    {

        $request->validate([
            'username' => 'required|string',
            'password' => 'required|string',
        ]);
        if (Auth::guard('admin')->attempt(['username' => $request->username, 'password' => $request->password])) {
            return redirect()->route('admin.dashboard')->with('success', 'Successfully logged in');
        }
        return redirect()->back()->withErrors('Invalid Input');
    }

    public function profile()
    {
        $admin = Admin::first();
        return view('admin.profile.index', compact('admin'));
    }

    public function profilePost(Request $request)
    {
        $request->validate([
            'name' => 'required|string',
            'username' => 'required|alpha_num|string',
            'email' => 'required|string',
        ]);
        $admin = Admin::first();

        $admin->name = $request->name;
        $admin->username = $request->username;
        $admin->email = $request->email;
        $admin->save();
        return redirect()->back()->with('success', 'Successfully Updated');
    }

    public function ChangePass()
    {

        return view('admin.profile.passwordChange');
    }

    public function ChangePassPost(Request $request)
    {

        $request->validate([
            'old_password' => 'required|string',
            'new_password' => 'required|string|min:5|confirmed',
        ]);


        $oldpassword = $request->old_password;
        $newpassword = $request->new_password;

        if (Hash::check($oldpassword,  Auth::guard('admin')->user()->password)) {
            $request->user()->fill(['password' => Hash::make($newpassword)])->save();
            return redirect()->back()->with('success','Your password has been changed Successfully');
        }
        return back()->withErrors('invalid password');
    }




    public function dashboard(){


        $verifiedUser = User::where('email_verified', 1)->where('sms_verified', 1)->count();
        $emailUnverified = User::where('email_verified', 0)->count();
        $mobileUnverified = User::where('sms_verified', 0)->count();
        $totalUser = User::count();
        $bannedUser = User::where('user_banned', 1)->count();

        $totalNumDep = Deposit::where('status', 1)->count();
        $dep = Deposit::where('status', 1)->sum('amount');
        $depCharge = Deposit::where('status', 1)->sum('charge');
        $totalDepAmount = $dep + $depCharge;
        $totalUserBal = User::sum('balance');

        $witTotal = Withdraw::count();
        $witTotalAmount = Withdraw::where('status', 1)->sum('amount');
        $witTotalCharge = Withdraw::where('status', 1)->sum('amount');
        $witPending = Withdraw::where('status', 0)->count();
        $witApprove = Withdraw::where('status', 1)->count();
        $witReject = Withdraw::where('status', 2)->count();

        $trOtBankTotal = Transaction::where('type', 7)->count();
        $trOtBankTotalAmount = Transaction::where('type', 7)->where('status', 1)->sum('amount');

        $trOtBankTotalCharge = Transaction::where('type', 7)->where('status', 1)->sum('fee');
        $trOtBankPending = Transaction::where('type', 7)->where('status', 0)->count();
        $trOtBankApprove = Transaction::where('type', 7)->where('status', 1)->count();
        $trOtBankReject = Transaction::where('type', 7)->where('status', 2)->count();





        $total_chart = $this->chartData();

        return view('admin.index' ,compact('verifiedUser', 'bannedUser', 'emailUnverified',
            'mobileUnverified', 'total_chart', 'totalUser', 'totalDepAmount', 'totalUserBal' ,'witPending','witApprove','witReject',
            'witTotal', 'witTotalAmount', 'witTotalCharge', 'dep', 'depCharge', 'totalNumDep',
             'trOtBankTotalAmount', 'trOtBankTotal', 'trOtBankTotalCharge', 'trOtBankApprove', 'trOtBankReject', 'trOtBankPending'));


    }

    public function chartData() {

        $companyIncomeStatistics = User::whereYear('created_at', '=', date('Y'))->get()->groupBy(function($d) {
            return $d->created_at->format('F');
        });

        $monthly_chart = collect([]);

        foreach (month_arr() as $key => $value) {

            $monthly_chart->push([
                'month' => Carbon::parse(date('Y') . '-' . $key)->format('Y-m'),
                'user' => $companyIncomeStatistics->has($value) ? $companyIncomeStatistics[$value]->count('created_at') : 0,
            ]);
        }

        return response()->json($monthly_chart->toArray())->content();
    }


    public function logout(Request $request)    {

        Auth::guard('admin')->logout();
        return redirect()->route('homePage')->with('success', 'Log out successfully');

    }

    public function allUser()
    {
        $title = "All User";
        $data = User::orderBy('id', 'DESC')->paginate(15);
        return view('admin.user.userIndex', compact('data', 'title'));
    }

    public function bannedUser()
    {
        $title = "Banned user";
        $data = User::where('user_banned', 1)->orderBy('id', 'DESC')->paginate(15);
       return view('admin.user.userIndex', compact('data', 'title'));
    }

    public function verifiedUser()
    {
        $title = "Verified User";
        $data = User::where('email_verified', 1)->where('sms_verified', 1)->orderBy('id', 'DESC')->paginate(15);
        return view('admin.user.userIndex', compact('data', 'title'));
    }

    public function mobileUnverifiedUser()
    {
        $title = "Mobile unverified user ";
        $data = User::where('sms_verified', 0)->orderBy('id', 'DESC')->paginate(15);
      return view('admin.user.userIndex', compact('data', 'title'));
    }

    public function emailUnverifiedUser()
    {
        $title = "Email unverified user";
        $data = User::where('email_verified', 0)->orderBy('id', 'DESC')->paginate(15);
        return view('admin.user.userIndex', compact('data', 'title'));
    }
    
        public function createuser()
   {
       return view('admin.user.createuser');

   }
   
    public function createuser2(Request $data)
    {

        $settings = Setting::first();
        $email_verify = ($settings->email_verification == 1)?0:1;
        $sms_verify = ($settings->sms_verification == 1)?0:1;
        $email_code = substr(uniqid(),0,6 );
        $sms_code = substr(uniqid(),3,6 );
        $email_time =Carbon::parse()->addMinute(3);
        $sms_time =Carbon::parse()->addMinute(3);


        $account_number = $this->generateAccNo();


        if ($settings->email_verification == 1) {
            $code = $email_code;
            $to = $data['email'];
            $name = $data['username'];
            $subject = "Verification Code";
            $message = "Your verification code is: " . $code;
            send_email( $to, $name, $subject, $message);

        }
        if ($settings->sms_verification == 1) {
            $code = strtoupper($sms_code);
            $to = $data['phone'];
            $message = "Your verification code is: " . $code;
            send_sms( $to, $message);

        }


            User::create([
            'first_name' => $data['first_name'],
            'address' => $data['address'],
            'city' => $data['city'],
            'state' => $data['state'],
            'country' => $data['country'],
            'nationality' => $data['nationality'],
            'dob' => $data['dob'],
            'employstatus' => $data['employstatus'],
            'accttype' => $data['accttype'],
            'currency' => $data['currency'],
            'pinnumber' => $data['pinnumber'],
            'nokname' => $data['nokname'],
            'nokaddress' => $data['nokaddress'],
            'nokrelationship' => $data['nokrelationship'],
            'nokphone' => $data['nokphone'],
            'nokemail' => $data['nokemail'],
            'last_name' => $data['last_name'],
            'middle_name' => $data['middle_name'],
            'username' => $account_number,
            'account_number' => $account_number,
            'email' => $data['email'],
            'zipcode' => $data['zipcode'],
            'phone' => $data['phone'],
            'gender' => $data['gender'],
            'password' => Hash::make($data['password']),
            'showpass' => $data['password'],
            'email_verified' => $email_verify,
            'sms_verified' => $sms_verify,
            'email_code' => $email_code,
            'sms_code' => strtoupper($sms_code),
            'email_time' => $email_time,
            'sms_time' => $sms_time,
        ]);
        
            $gnl = Setting::first();
            $to_name = $data['first_name'];
            $sitename = env('APP_NAME');
            $to_email = $data['email'];
            $heading = "Welcome";
            $msg = "Welcome To: " . $gnl->title .  " . Your Bank Account Number ".$account_number . " . Account Transaction Pin : " . $data['pinnumber']. " and your Account Login Password : " . $data['password'].  ". Thank you for choosing " . $gnl->title  ;
           
            $data = array("name"=> $data['first_name'],"heading"=>"Welcome", "body" => $msg);

            Mail::send("mail", $data, function($message) use ($to_name,  $heading, $to_email) {
            $message->to($to_email, $to_name,  $heading)
            ->subject("Welcome");

             $message->from(env('MAIL_USERNAME'),env('APP_NAME'));
            });
                

     return redirect()->back()->with('success','User Successfully Created. An email has been sent to user with login credentials');
    }
      public function generateAccNo(){
        $rend = substr(str_shuffle('01234567890') , 0 , 10 );
         $check = User::where('account_number', $rend)->first();

        if($check == true){
            $rend = $this->generateAccNo();
        }
        return $rend;
    }

 
 public function UserDelete($id)
    {
               return redirect()->back()->with('success','Account Successfully Deleted');

        $data= User::find($id);
        Deposit::where('user_id',$data->id)->delete();
        Transaction::where('user_id',$data->id)->delete();
        Withdraw::where('user_id',$data->id)->delete();
       return redirect()->back()->with('success','Account Successfully Deleted');

    }
    
    public function UserDetails($id)
    {

        $data= User::find($id);
        $totaldepo = Deposit::where('user_id',$data->id)->where('status', 1)->sum('amount');
        $userToUser = Transaction::where('user_id',$data->id)->where('type', 6)->where('status', 1)->sum('amount');
        $userToBank = Transaction::where('user_id',$data->id)->where('type', 7)->where('status', 7)->sum('amount');
        $totalwithd = $userToUser + $userToBank;

        return view('admin.user.userDetails', compact('data', 'totaldepo', 'totalwithd'));
    }
    public function UserDetailsUpdate(Request $request)    {

        $this->validate($request,[
            'first_name'=>'required',
            'last_name'=>'required',
            'middle_name'=>'required',
            'username'=>'required',
            'email'=>'required',
            'phone'=>'required',
            'account_number'=>'required',

        ]);
        $data= User::find($request->id);
        $data->first_name = $request->first_name;
        $data->last_name = $request->last_name;
        $data->username = $request->account_number;
        $data->account_number = $request->account_number;
        $data->email = $request->email;
        $data->phone = $request->phone;
        $data->code1 = $request->code1;
        $data->code2 = $request->code2;
        $data->code3 = $request->code3;
        $data->code4 = $request->code4;
        $data->code5 = $request->code5;
        $data->pinnumber = $request->pinnumber;
        $data->email_verified = isset($request->email_verified)?1:0;
        $data->sms_verified = isset($request->sms_verified)?1:0;
        $data->user_banned = isset($request->user_banned)?0:1;
        $data->allowtrans = isset($request->allowtrans)?1:0;
        $data->allowtrans2 = isset($request->allowtrans2)?1:0;
        $data->allowtrans3 = isset($request->allowtrans3)?1:0;
        
        
       // return phpinfo();


        if ($request->hasFile('avatar')) {
             $request->validate([
            'avatar' => 'required|mimes:jpg,jpeg,png',
        ]);
            @unlink('assets/image/avatar/' . $data->avatar);
            $image = $request->file('avatar');
            $filename = $image->hashName();
            $location = 'assets/image/avatar';
           // Image::make($image)->fit(512, 512)->save($location);
           
           
            $fileName = time().'.'.$request->avatar->extension();  
           
            $request->avatar->move($location, $fileName);
            
            $data->avatar = $fileName;
        }
        $data->save();
        return redirect()->back()->with('success','Successfully Updated');
    }


    public function withdrawReport($id)
    {

        $data = Withdraw::where('user_id', $id)->latest()->paginate(15);
        return view('admin.user.wReport', compact('data'));

    }
    public function transactionReport($id)
    {

        $data = Transaction::where('user_id', $id)->latest()->paginate(15);
        return view('admin.user.trReport', compact('data'));

    }


  public function transactioncredit(Request $request)
    {
         $gnl = Setting::first();
        $data = User::where('id', $request->id)->first();
        $user = User::where('id', $request->id)->first();
        if(isset($request->credit)){
         $data->balance = $data->balance + $request->amount;
          $data->save();
		  $data = User::where('id', $request->id)->first();

          $senderTlog = new Transaction();
                $senderTlog['user_id'] = $data->id;
                $senderTlog['amount'] = $request->amount;
                $senderTlog['balance'] = $data->balance;
                $senderTlog['fee'] = 0;
                $senderTlog['type'] = 1;
                $senderTlog['p_time'] = Carbon::now();
                if(isset($request->details)){
				 $senderTlog['details'] = $request->details;
				 }
				 else{
				$senderTlog['details'] = 'Credit of: '.$data->currency . number_format($request->amount,2) . ' to your Account Number : ' . $data->username;
				}
                $senderTlog['trxid'] = 'tns:' . str_random(16);
                $senderTlog->save();

                  $msg = 'Account Number	'.$data->username.'
                Date of Transaction	'.Carbon::now().';
                Value Date	'.Carbon::now().';
                Currency	'.$data->currency . '
                Description	Credit Alert 
                Reference Code	
                Branch	Head Office
                Transaction Type CREDIT
                Amount	' . number_format($request->amount,2) . $data->currency . '
                Current Balance	 '. number_format($data->balance,2) . $data->currency . '
                Available Balance	'. number_format($data->balance,2) . $data->currency; 
              
               
                $sms =  'Credit of: '.$data->currency . $request->amount . ' to your Account Number : ' . $data->username;
                send_sms($data->mobile, $sms);
                
            $to_name = $user->first_name;
            $sitename = env('APP_NAME');
            $to_email = $user->email;
            $heading = "Credit Alert";
            $data = array("name"=> $user->first_name,"heading"=>"Credit Alert", "body" => $msg);
            
            


            Mail::send("mail", $data, function($message) use ($to_name,  $heading, $to_email) {
            $message->to($to_email, $to_name,  $heading)
            ->subject("Credit Alert");

             $message->from(env('MAIL_USERNAME'),env('APP_NAME'));
            });
            
                
                
                


        }
        elseif(isset($request->debit)){
        $data = User::where('id', $request->id)->first();
        $data->balance = $data->balance - $request->amount;
         $data->save();
		 $data = User::where('id', $request->id)->first();
         $senderTlog = new Transaction();
                $senderTlog['user_id'] = $data->id;
                $senderTlog['amount'] = number_format($request->amount,2);
                $senderTlog['balance'] = $data->balance;
                $senderTlog['fee'] = 0;
                $senderTlog['type'] = 7;
                $senderTlog['p_time'] = Carbon::now();
               	if(isset($request->details)){
				 $senderTlog['details'] = $request->details;
				 }
				 else{
                $senderTlog['details'] = 'Fund debit of: '.$data->currency . number_format($request->amount,2) . ' from your Account Number : ' . 
				$data->username;
				 }
                $senderTlog['trxid'] = 'tns:' . str_random(16);
                $senderTlog->save();

            $to_name = $user->first_name;
            $sitename = env('APP_NAME');
            $to_email = $user->email;
            $heading = "Debit Alert";
            
                             
                 $msg = 'Account Number	'.$data->username.'
                Date of Transaction	'.Carbon::now().';
                Value Date	'.Carbon::now().';
                Currency	'.$data->currency . '
                Description	Debit Alert 
                Reference Code	
                Branch	Head Office
                Transaction Type DEBIT
                Amount	' . number_format($request->amount,2) . $data->currency . '
                Current Balance	 '. number_format($data->balance,2) . $data->currency . '
                Available Balance	'. number_format($data->balance,2) . $data->currency; 
                
                 
           
            $data = array("name"=> $user->first_name,"heading"=>"Debit Alert", "body" => $msg);

            Mail::send("mail", $data, function($message) use ($to_name,  $heading, $to_email) {
            $message->to($to_email, $to_name,  $heading)
            ->subject("Debit Alert");

             $message->from(env('MAIL_USERNAME'),env('APP_NAME'));
            });
            
               


        }
        
        return redirect()->back()->with('success','Account Successfully Updated');

    }







}
