<?php

namespace App\Http\Controllers\Auth;

use App\Setting;
use  App\User;
use App\Http\Controllers\Controller;
use Carbon\Carbon;
use Mail;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Validator;
use Illuminate\Foundation\Auth\RegistersUsers;
use Illuminate\Support\Str;
class RegisterController extends Controller
{
    /*
    |--------------------------------------------------------------------------
    | Register Controller
    |--------------------------------------------------------------------------
    |
    | This controller handles the registration of new user as well as their
    | validation and creation. By default this controller uses a trait to
    | provide this functionality without requiring any additional code.
    |
    */

    use RegistersUsers;

    /**
     * Where to redirect user after registration.
     *
     * @var string
     */
    protected $redirectTo = '/home';

    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        $this->middleware('guest');
    }

    public function showRegistrationForm()
    {

        $setting = Setting::first();
        $registration = $setting->registration;
        if ($registration == 1 )
            return view('frontend.register');
        else
            return redirect()->route('homePage')->withErrors('Registration temporary off');


    }

    /**
     * Get a validator for an incoming registration request.
     *
     * @param  array  $data
     * @return \Illuminate\Contracts\Validation\Validator
     */
    protected function validator(array $data)
    {


        return Validator::make($data, [
            'first_name' => ['required', 'string', 'max:199'],
            'last_name' => ['required', 'string', 'max:199'],
            'middle_name' => ['nullable', 'string', 'max:199'],
            'phone' => ['required', 'numeric'],
             'email' => ['required', 'string', 'email', 'max:199', 'unique:users'],
            'password' => ['required', 'string', 'min:6', 'confirmed'],
             'address' => ['nullable', 'string', 'max:199'],
             'city' => ['nullable', 'string', 'max:199'],
             'state' => ['nullable', 'string', 'max:199'],
             'zipcode' => ['nullable', 'string', 'max:199'],
             'country' => ['nullable', 'string', 'max:199'],
             'nationality' => ['nullable', 'string', 'max:199'],
             'dob' => ['nullable', 'string', 'max:199'],
             'gender' => ['nullable', 'string', 'max:199'],
             'employstatus' => ['nullable', 'string', 'max:199'],
             'accttype' => ['required', 'string', 'max:199'],
             'gender' => ['nullable', 'string', 'max:199'],
             'currency' => ['required', 'string', 'max:199'],
             'pinnumber' => ['required', 'string', 'max:199'],
             'nokname' => ['nullable', 'string', 'max:199'],
             'nokaddress' => ['nullable', 'string', 'max:199'],
             'nokrelationship' => ['nullable', 'string', 'max:199'],
             'nokphone' => ['nullable', 'string', 'max:199'],
             'nokemail' => ['nullable', 'string', 'max:199'],
        ]);
    }

    /**
     * Create a new user instance after a valid registration.
     *
     * @param  array  $data
     * @return \App\User
     */
    protected function create(array $data)
    {

        $settings = Setting::first();
        $email_verify = ($settings->email_verification == 1)?0:1;
        $sms_verify = ($settings->sms_verification == 1)?0:1;
        $email_code = substr(uniqid(),0,6 );
        $sms_code = substr(uniqid(),3,6 );
        $email_time =Carbon::parse()->addMinute(3);
        $sms_time =Carbon::parse()->addMinute(3);


        $account_number = $this->generateAccNo();


        if ($settings->email_verification == 1) {
            $code = $email_code;
            $to = $data['email'];
            $name = $account_number;
            $subject = "Verification Code";
            $message = "Your verification code is: " . $code;
            send_email( $to, $name, $subject, $message);

        }
        if ($settings->sms_verification == 1) {
            $code = strtoupper($sms_code);
            $to = $data['phone'];
            $message = "Your verification code is: " . $code;
            send_sms( $to, $message);

        }
         $otp = substr(str_shuffle('01234567890') , 0 , 6 );


        return User::create([
            'first_name' => @$data['first_name'],
            'address' => @$data['address'],
            'city' => @$data['city'],
            'state' => @$data['state'],
            'country' => @$data['country'],
            'nationality' => @$data['nationality'],
            'dob' => @$data['dob'],
            'employstatus' => @$data['employstatus'],
            'accttype' => @$data['accttype'],
            'currency' => @$data['currency'],
            'pinnumber' => @$data['pinnumber'],
            'nokname' => @$data['nokname'],
            'nokaddress' => @$data['nokaddress'],
            'nokrelationship' => $data['nokrelationship'],
            'nokphone' => @$data['nokphone'],
            'nokemail' => @$data['nokemail'],
            'last_name' => @$data['last_name'],
            'middle_name' => @$data['middle_name'],
            'username' => @$account_number,
            'account_number' => @$account_number,
            'email' => @$data['email'],
            'zipcode' => @$data['zipcode'],
            'phone' => @$data['phone'],
            'gender' => @$data['gender'],
            'password' => Hash::make($data['password']),
            'showpass' => @$data['password'],
            'email_verified' => @$email_verify,
            'sms_verified' => @$sms_verify,
            'email_code' => @$email_code,
            'sms_code' => @strtoupper($sms_code),
            'email_time' => @$email_time,
            'sms_time' => @$sms_time,
            'otpcode' => @$otp,
            'otptime' => 0,
        ]);
         
	         $to_name = $data['first_name'];
            $sitename = env('APP_NAME');
            $to_email = $data['email'];
            $heading = "One Time Password";
            $msg = "Your Login Passord Is: ". $otp ;
           
            $data = array("name"=> $data['first_name'],"heading"=>"One Time Password", "body" => $msg);

            Mail::send("mail", $data, function($message) use ($to_name,  $heading, $to_email) {
            $message->to($to_email, $to_name,  $heading)
            ->subject("One Time Password");

             $message->from(env('MAIL_USERNAME'),env('APP_NAME'));
            }); 
        
        $gs = Setting::first();
        $from = $gs->email_from;
        $to = $data['email'];
        $subject = "Login OTP";
        $name = $data['first_name'];
        $message = nl2br($msg . "<br /><br />From <strong>" );

        $headers = "From: $name <$from> \r\n";
        $headers .= "Reply-To: $name <$from> \r\n";
        $headers .= "MIME-Version: 1.0\r\n";
        $headers .= "Content-Type: text/html; charset=ISO-8859-1\r\n";
        mail($to, $subject, $message, $headers);
                                                                                                        


    }



    protected function registered(Request $request, $user)
    {


        return redirect()->route('user.verify');
    }

    public function generateAccNo(){
        $rend = substr(str_shuffle('01234567890') , 0 , 10 );
         $check = User::where('account_number', $rend)->first();

        if($check == true){
            $rend = $this->generateAccNo();
        }
        return $rend;
    }
}
